@@ -1,41 +1,3 @@
-#' Mann-Whitney-Wilcoxon ranks test when data are in groups.
-#'
-#' Calculate a Mann-Whitney-Wilcoxon test for a difference between treatment
-#' levels using nested ranks.  This test can be used when observations are
-#' structured into several groups and each group has received both treatment
-#' levels.  The p-value is determined via bootstrapping.  This test is intended
-#' to be analogous to a mixed-model extension of the \code{\link{wilcox.test}},
-#' for which treatment is a fixed effect and group membership is a random
-#' effect.
-#'
-#' The main function is \code{\link{nestedRanksTest}}, which includes a
-#' formula interface implementing the familiar \code{"|"} syntax for
-#' specifying group membership on the right-hand side of the formula.
-#' The value returned is a list of class \code{'htest_boot'}, which
-#' extends class \code{'htest'}.  \code{print} and \code{plot} methods
-#' are provided to print and visualise results.
-#'
-#' These statistical tools were developed in collaboration with Peter E.
-#' Smouse (Rutgers University) and Victoria L. Sork (UCLA) and were funded by
-#' U.S. National Science Foundation awards NSF-DEB-0514956 and
-#' NSF-DEB-0516529.
-#'
-#' @references
-#' Thompson, P. G., Smouse, P. E., Scofield, D. G. and Sork, V. L. (2014)
-#' What seeds tell us about birds: a multi-year analysis of acorn woodpecker
-#' foraging movements.  \emph{Movement Ecology} 2:12.
-#' \url{http://www.movementecologyjournal.com/content/2/1/12}
-#'
-#' \url{https://github.com/douglasgscofield/nestedRanksTest}
-#'
-#' @docType package
-#'
-#' @name nestedRanksTest-package
-#'
-NULL
-
-
-
 #' Mann-Whitney-Wilcoxon ranks test when data are in groups.
 #'
 #' The statistic for the nested ranks test is a Z-score calculated by
@@ -387,162 +349,3 @@ nestedRanksTest_weights <- function(x, groups) {
     w$weights <- w$n1.n2 / sum(w$n1.n2)
     return(w)
 }
-
-
-
-#' Print result of \code{nestedRanksTest}.
-#'
-#' \code{print.htest_boot} prints the return value of
-#' \code{\link{nestedRanksTest}}, a list of class \code{'htest_boot'}
-#' which extends class \code{'htest'} by including group weights, the
-#' number of bootstrap iterations, and the complete null distribution.
-#' The latter is not printed by this function; it may be visualised with
-#' \code{\link{plot.htest_boot}}.
-#'
-#' @param  x      Value of class \code{'htest_boot'} as returned by
-#'                \code{nestedRanksTest}.
-#' @param  \dots  Additional arguments passed to \code{print.htest}.
-#'
-#' @return The value of x is returned invisibly.
-#'
-#' @examples
-#' data(woodpecker_multiyear)
-#' ## n.iter set to 1000 to shorten completion time
-#' res <- nestedRanksTest(Distance ~ Year | Granary, n.iter = 1000,
-#'                        data = woodpecker_multiyear,
-#'                        subset = Species == "agrifolia")
-#' class(res)
-#' print(res)
-#'
-#' @seealso \code{\link{nestedRanksTest}} for the test description,
-#'   \code{\link{plot.htest_boot}} for a graphical plot of test
-#'   results, and \code{\link{print.htest}} for the print method of
-#'   the base class.
-#'
-#' @export
-#'
-print.htest_boot <- function(x, ...) {
-    NextMethod(x, ...)
-    cat("bootstrap iterations =", x$n.iter, "\ngroup weights:\n")
-    print(x$weights)
-    invisible(x)
-}
-
-
-
-#' Diagnostic plot of result from nestedRanksTest.
-#'
-#' \code{plot.htest_boot} creates a diagnostic plot using the return value
-#' of \code{\link{nestedRanksTest}}, a list of class \code{'htest_boot'}.
-#' The plot contains a histogram of the null distribution generated by
-#' bootstrapping plotted with \code{\link{hist}}, and a verticle line
-#' indicating the observed value plotted with \code{\link{abline}}.
-#'
-#' If there is no null distribution included in the class, because the
-#' options \code{lightweight = TRUE} or \code{n.iter = 1} were given to
-#' \code{nestedRanksTest}, this function produces an error.
-#'
-#' @param  x       Value of class \code{'htest_boot'} as returned by
-#'                 \code{nestedRanksTest}.
-#' @param  breaks  The number of breaks to use when plotting the distribution,
-#'                 the default is calculated from \code{n.iter} of the call to
-#'                 \code{nestedRanksTest}.
-#' @param  col     Fill color for histogram bars, passed to \code{hist}.
-#' @param  border  Border color for histogram bars, passed to \code{hist}.
-#' @param  main    Main title, passed to \code{hist}.
-#' @param  xlab    X-axis label, passed to \code{hist}.
-#' @param  ylab    Y-axis label, passed to \code{hist}.
-#' @param  p.col   Observed value line colour, passed to \code{abline}.
-#' @param  p.lty   Observed value line type, passed to \code{abline}.
-#' @param  p.lwd   Observed value line width, passed to \code{abline}.
-#' @param  \dots   Additional arguments passed to \code{hist} and
-#'                 \code{abline} for plotting.
-#'
-#' @return None
-#'
-#' @examples
-#' require(graphics)
-#'
-#' data(woodpecker_multiyear)
-#'
-#' ## n.iter set to 1000 to shorten completion time
-#' res.a <- nestedRanksTest(Distance ~ Year | Granary, n.iter = 1000,
-#'                          data = woodpecker_multiyear,
-#'                          subset = Species == "agrifolia")
-#' res.l <- nestedRanksTest(Distance ~ Year | Granary, n.iter = 1000,
-#'                          data = woodpecker_multiyear,
-#'                          subset = Species == "lobata")
-#'
-#' opa = par(mfrow = c(2, 1))
-#' ## Defaults
-#' plot(res.l)
-#' ## Modify colours, line type and main title
-#' plot(res.a, main = "Quercus agrifolia", col = "lightgreen",
-#'      p.col = "brown4", p.lty = 1)
-#' par(opa)
-#'
-#' @seealso \code{\link{nestedRanksTest}} for test description,
-#'     \code{\link{print.htest_boot}} for printing test results,
-#'     and \code{\link{hist}} and \code{\link{abline}} for plotting options.
-#'
-#' @keywords hplot
-#'
-#' @export
-#'
-plot.htest_boot <- function(x, breaks, col = "lightblue", border = NA,
-                            main = paste(sep = "",
-                                         x$method, ", ", x$data.name, "\n",
-                                         names(x$statistic), " = ",
-                                         round(x$statistic,
-                                               ceiling(log10(x$n.iter))),
-                                         ", P = ", x$p.value),
-                            xlab = "Distribution of Z-scores",
-                            ylab = paste(sep = "",
-                                         "Frequency (out of ", x$n.iter, ")"),
-                            p.col = "red", p.lty = 2, p.lwd = 2,
-                            ...) {
-    if (is.null(x$null.distribution) || x$n.iter == 1)
-        stop(deparse(substitute(x)), " does not contain a null distribution")
-    if (missing(breaks))
-        breaks <- min(ceiling(x$n.iter / 50), 100)
-    hist(x$null.distribution, breaks = breaks, col = col, border = border,
-        main = main, xlab = xlab, ylab = ylab, ...)
-    abline(v = x$statistic, col = p.col, lty = p.lty, lwd = p.lwd, ...)
-}
-
-
-
-#' Distances acorns of two oak species were carried by acorn woodpeckers in
-#' two different years.
-#'
-#' A dataset containing distances acorns of two oak species were carried by
-#' acorn woodpeckers (\emph{Melanerpes formicivorus}) to their granaries, in
-#' two different years for each oak species.  Data were collected in oak
-#' savanna habitat in central California.  Acorn woodpeckers store acorns in
-#' central granaries, and different woodpecker social groups maintain
-#' different granaries. The variables are as follows:
-#' \itemize{
-#'     \item Species, the species of oak for the observed acorn ("lobata" for
-#'         \emph{Quercus lobata}, "agrifolia" for \emph{Quercus agrifolia})
-#'     \item Year, the year of observation (2002 and 2004 for
-#'         \emph{Quercus lobata}, 2006 and 2007 for \emph{Quercus agrifolia})
-#'     \item Granary, the woodpecker granary from which the acorn was collected
-#'     \item Distance, distance in metres from the acorn source tree to the
-#'         granary
-#' }
-#'
-#' @references
-#' Thompson, P. G., Smouse, P. E., Scofield, D. G. and Sork, V. L. (2014)
-#' What seeds tell us about birds: a multi-year analysis of acorn woodpecker
-#' foraging movements.  \emph{Movement Ecology} 2:12.
-#' \url{http://www.movementecologyjournal.com/content/2/1/12}
-#'
-#' @format   Data frame with 534 rows and 4 variables.
-#' @author   Douglas G. Scofield \email{douglasgscofield@@gmail.com}
-#' @source   Dataset originates from the lab of Victoria L. Sork
-#'           \email{vlsork@@ucla.edu} and is used with permission.
-#' @docType  data
-#' @name     woodpecker_multiyear
-#'
-NULL
-
